@@ -77,13 +77,18 @@ const char *CommonTemplates::DisclaimerTemplate()
     return "/* This file is autogenerated. DO NOT CHANGE. All changes will be lost */\n\n";
 }
 
-const char *CommonTemplates::PreambleTemplate()
+const char *CommonTemplates::PragmaOnce()
+{
+    return "#pragma once";
+}
+
+const char *CommonTemplates::HeaderGuardBeginTemplate()
 {
     return "#ifndef $header_guard$\n"
            "#define $header_guard$\n";
 }
 
-const char *CommonTemplates::FooterTemplate()
+const char *CommonTemplates::HeaderGuardEndTemplate()
 {
     return "#endif // $header_guard$\n";
 }
@@ -377,6 +382,19 @@ const char *CommonTemplates::SwapDeclarationTemplate()
            "}\n";
 }
 
+const char *CommonTemplates::QVariantOperatorDeclarationTemplate()
+{
+    return "$export_macro$Q_IMPLICIT operator QVariant() const;\n";
+}
+
+const char *CommonTemplates::QVariantOperatorDefinitionTemplate()
+{
+    return "$classname$::operator QVariant() const\n"
+           "{\n"
+           "    return QVariant::fromValue(*this);\n"
+           "}\n";
+}
+
 const char *CommonTemplates::EqualityDeclarationTemplate()
 {
     return "friend $export_macro$bool comparesEqual(const $classname$ &lhs, "
@@ -1020,6 +1038,12 @@ const char *CommonTemplates::ExportMacroTemplate()
            "#endif\n";
 }
 
+const char *CommonTemplates::CustomJsonHanderTemplate()
+{
+    return "QT_PREPEND_NAMESPACE(QtProtobufWellKnownTypesPrivate)::"
+           "register$type_name$CustomJsonHandler();\n";
+}
+
 const char *CommonTemplates::MocIncludeTemplate()
 {
     return "#include \"$source_file$\"\n";
