@@ -98,7 +98,7 @@ std::string common::buildExportMacro(bool addTrailingSpace)
 std::string common::getNestedNamespace(const Descriptor *type, std::string_view separator)
 {
     assert(type != nullptr);
-    std::string namespaces = type->file()->package();
+    std::string namespaces{ type->file()->package() };
 
     std::string nestingNamespaces;
     const Descriptor *containingType = type->containing_type();
@@ -147,11 +147,10 @@ std::map<std::string, std::string> common::getNestedScopeNamespace(const std::st
 
 TypeMap common::produceQtTypeMap(const Descriptor *type, const Descriptor *scope)
 {
-    std::string namespaces = getFullNamespace(type, "::");
     std::string scopeNamespaces = getScopeNamespace(type, scope);
     std::string qmlPackage = getFullNamespace(type, ".");
 
-    std::string name = type->name();
+    std::string name{ type->name() };
     std::string fullName = name;
     std::string scopeName = name;
 
@@ -176,7 +175,7 @@ TypeMap common::produceOverriddenTypeMap(const Descriptor *type, const Descripto
     std::string namespaces = getFullNamespace(type, "::");
     std::string qmlPackage = getFullNamespace(type, ".");
 
-    std::string name = type->name();
+    std::string name{ type->name() };
     std::string listName;
     if (type->full_name() == "google.protobuf.Any") {
         namespaces = "QtProtobuf";
@@ -340,18 +339,15 @@ TypeMap common::produceSimpleTypeMap(FieldDescriptor::Type type)
 
 MethodMap common::produceMethodMap(const MethodDescriptor *method, const std::string &scope)
 {
-    std::string inputTypeName = method->input_type()->full_name();
-    std::string outputTypeName = method->output_type()->full_name();
-    std::string methodName = method->name();
-    std::string methodNameUpper = method->name();
+    std::string inputTypeName{ utils::replace(method->input_type()->full_name(), ".", "::") };
+    std::string outputTypeName{ utils::replace(method->output_type()->full_name(), ".", "::")  };
+    std::string methodName{ method->name() };
+    std::string methodNameUpper{ method->name() };
     methodNameUpper[0] = static_cast<char>(utils::toAsciiUpper(methodNameUpper[0]));
-    inputTypeName = utils::replace(inputTypeName, ".", "::");
-    outputTypeName = utils::replace(outputTypeName, ".", "::");
 
-    std::string senderName = methodNameUpper;
-    senderName += "Sender";
+    std::string senderName = std::move(methodNameUpper) + "Sender";
 
-    std::string serviceName = method->service()->name();
+    std::string serviceName{ method->service()->name() };
 
     //Make sure that we don't clash the same stream names from different services
     std::string senderQmlName = serviceName;
@@ -389,9 +385,9 @@ MethodMap common::produceMethodMap(const MethodDescriptor *method, const std::st
 
 TypeMap common::produceServiceTypeMap(const ServiceDescriptor *service, const Descriptor *scope)
 {
-    const std::string name = "Service";
-    const std::string fullName = "Service";
-    const std::string scopeName = service->name();
+    const std::string name{ "Service" };
+    const std::string fullName{ "Service" };
+    const std::string scopeName{ service->name() };
     static const std::string exportMacro = common::buildExportMacro();
 
     const std::string namespaces = getFullNamespace(service, "::");
@@ -409,16 +405,16 @@ TypeMap common::produceServiceTypeMap(const ServiceDescriptor *service, const De
 
 TypeMap common::produceClientTypeMap(const ServiceDescriptor *service, const Descriptor *scope)
 {
-    const std::string name = "Client";
-    const std::string fullName = "Client";
-    const std::string scopeName = service->name();
+    const std::string name{ "Client" };
+    const std::string fullName{ "Client" };
+    const std::string scopeName{ service->name() };
     static const std::string exportMacro = common::buildExportMacro();
 
     const std::string namespaces = getFullNamespace(service, "::");
     const std::string scopeNamespaces = getScopeNamespace(namespaces,
                                                           getFullNamespace(scope, "::"));
 
-    const std::string serviceName =  service->full_name();
+    const std::string serviceName{ service->full_name() };
     return { { "classname", name },
              { "classname_low_case", utils::deCapitalizeAsciiName(name) },
              { "full_type", fullName },
@@ -431,9 +427,9 @@ TypeMap common::produceClientTypeMap(const ServiceDescriptor *service, const Des
 
 TypeMap common::produceQmlClientTypeMap(const ServiceDescriptor *service, const Descriptor *scope)
 {
-    const std::string name = "QmlClient";
-    const std::string fullName = "QmlClient";
-    const std::string serviceName = service->name();
+    const std::string name{ "QmlClient" };
+    const std::string fullName{ "QmlClient" };
+    const std::string serviceName{ service->name() };
     static const std::string exportMacro = common::buildExportMacro();
 
     const std::string namespaces = getFullNamespace(service, "::");
@@ -528,12 +524,13 @@ TypeMap common::produceTypeMap(const FieldDescriptor *field, const Descriptor *s
 PropertyMap common::producePropertyMap(const OneofDescriptor *oneof, const Descriptor *scope)
 {
     assert(oneof != nullptr);
+    assert(scope != nullptr);
 
     PropertyMap propertyMap;
     propertyMap["optional_property_name"] = qualifiedCppName(qualifiedQmlName(oneof->name()));
     propertyMap["optional_property_name_cap"] = utils::capitalizeAsciiName(oneof->name());
     auto scopeTypeMap = produceMessageTypeMap(scope, nullptr);
-    propertyMap["classname"] = scope != nullptr ? scopeTypeMap["classname"] : "";
+    propertyMap["classname"] = scopeTypeMap["classname"];
     propertyMap["dataclassname"] = propertyMap["classname"] + CommonTemplates::DataClassName();
     propertyMap["type"] = propertyMap["optional_property_name_cap"] + "Fields";
     propertyMap["export_macro"] = common::buildExportMacro();
@@ -544,6 +541,7 @@ PropertyMap common::producePropertyMap(const OneofDescriptor *oneof, const Descr
 PropertyMap common::producePropertyMap(const FieldDescriptor *field, const Descriptor *scope)
 {
     assert(field != nullptr);
+    assert(scope != nullptr);
 
     PropertyMap propertyMap = produceTypeMap(field, scope);
 
@@ -568,7 +566,7 @@ PropertyMap common::producePropertyMap(const FieldDescriptor *field, const Descr
     auto scopeTypeMap = produceMessageTypeMap(scope, nullptr);
     propertyMap["key_type"] = "";
     propertyMap["value_type"] = "";
-    propertyMap["classname"] = scope != nullptr ? scopeTypeMap["classname"] : "";
+    propertyMap["classname"] = scopeTypeMap["classname"];
     propertyMap["dataclassname"] = propertyMap["classname"] + CommonTemplates::DataClassName();
     propertyMap["number"] = std::to_string(field->number());
 
@@ -597,12 +595,13 @@ PropertyMap common::producePropertyMap(const FieldDescriptor *field, const Descr
     return propertyMap;
 }
 
-std::string common::qualifiedCppName(const std::string &name)
+std::string common::qualifiedCppName(std::string_view name)
 {
-    return utils::contains(CommonTemplates::ListOfCppExceptions(), name) ? name + "_" : name;
+    return utils::contains(CommonTemplates::ListOfCppExceptions(), name) ? std::string{ name } + "_"
+                                                                         : std::string{ name };
 }
 
-std::string common::qualifiedQmlName(const std::string &name)
+std::string common::qualifiedQmlName(std::string_view name)
 {
     std::string fieldName(name);
     const std::vector<std::string> &searchExceptions = CommonTemplates::ListOfQmlExceptions();
@@ -799,9 +798,9 @@ std::string common::collectFieldFlags(const FieldDescriptor *field)
     return flags;
 }
 
-bool common::isExtraNamespacedFile(const std::string &file)
+bool common::isExtraNamespacedFile(std::string_view file)
 {
-    return m_extraNamespacedFiles.find(file) != m_extraNamespacedFiles.end();
+    return m_extraNamespacedFiles.find(std::string{ file }) != m_extraNamespacedFiles.end();
 }
 
 void common::setExtraNamespacedFiles(const std::set<std::string> &files)
